#!/home/ktietz/src/ci_fix/portpicker_1623148774623/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold/bin/python
# EASY-INSTALL-SCRIPT: 'portpicker==1.3.1','portserver.py'
__requires__ = 'portpicker==1.3.1'
__import__('pkg_resources').run_script('portpicker==1.3.1', 'portserver.py')
